==> apache-druid-27.0.0-src.tar.gz: apache-druid-27.0.0-src/processing/src/main/java/org/apache/druid/math/expr/vector/ObjectOutObjectsInFunctionVectorProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.math.expr.vector;

import org.apache.druid.math.expr.ExpressionType;

import javax.annotation.Nullable;

public abstract class ObjectOutObjectsInFunctionVectorProcessor
    extends BivariateFunctionVectorObjectProcessor<Object[], Object[], Object[]>
{
  final ExpressionType expressionType;

  protected ObjectOutObjectsInFunctionVectorProcessor(
      ExprVectorProcessor<Object[]> left,
      ExprVectorProcessor<Object[]> right,
      int maxVectorSize,
      ExpressionType expressionType
  )
  {
    super(
        CastToTypeVectorProcessor.cast(left, expressionType),
        CastToTypeVectorProcessor.cast(right, expressionType),
        new Object[maxVectorSize]
    );
    this.expressionType = expressionType;
  }

  @Nullable
  protected abstract Object processValue(@Nullable Object leftVal, @Nullable Object rightVal);

  @Override
  void processIndex(Object[] in1, Object[] in2, int i)
  {
    outValues[i] = processValue(in1[i], in2[i]);
  }

  @Override
  void processNull(int i)
  {
    outValues[i] = null;
  }

  @Override
  ExprEvalVector<Object[]> asEval()
  {
    return new ExprEvalObjectVector(outValues);
  }

  @Override
  public ExpressionType getOutputType()
  {
    return expressionType;
  }
}

==> apache-druid-32.0.1-src.tar.gz: apache-druid-32.0.1-src/processing/src/main/java/org/apache/druid/math/expr/vector/ObjectOutObjectsInFunctionVectorProcessor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.math.expr.vector;

import org.apache.druid.math.expr.ExpressionType;

import javax.annotation.Nullable;

public abstract class ObjectOutObjectsInFunctionVectorProcessor
    extends BivariateFunctionVectorObjectProcessor<Object[], Object[], Object[]>
{
  final ExpressionType expressionType;

  protected ObjectOutObjectsInFunctionVectorProcessor(
      ExprVectorProcessor<Object[]> left,
      ExprVectorProcessor<Object[]> right,
      int maxVectorSize,
      ExpressionType expressionType
  )
  {
    super(
        CastToTypeVectorProcessor.cast(left, expressionType, maxVectorSize),
        CastToTypeVectorProcessor.cast(right, expressionType, maxVectorSize),
        new Object[maxVectorSize]
    );
    this.expressionType = expressionType;
  }

  @Nullable
  protected abstract Object processValue(@Nullable Object leftVal, @Nullable Object rightVal);

  @Override
  void processIndex(Object[] in1, Object[] in2, int i)
  {
    outValues[i] = processValue(in1[i], in2[i]);
  }

  @Override
  void processNull(int i)
  {
    outValues[i] = null;
  }

  @Override
  ExprEvalVector<Object[]> asEval()
  {
    return new ExprEvalObjectVector(outValues, expressionType);
  }

  @Override
  public ExpressionType getOutputType()
  {
    return expressionType;
  }
}
